import pysam.utils

annotate = pysam.utils.PysamDispatcher('bcftools', 'annotate')
call = pysam.utils.PysamDispatcher('bcftools', 'call')
cnv = pysam.utils.PysamDispatcher('bcftools', 'cnv')
concat = pysam.utils.PysamDispatcher('bcftools', 'concat')
consensus = pysam.utils.PysamDispatcher('bcftools', 'consensus')
convert = pysam.utils.PysamDispatcher('bcftools', 'convert')
csq = pysam.utils.PysamDispatcher('bcftools', 'csq')
filter = pysam.utils.PysamDispatcher('bcftools', 'filter')
gtcheck = pysam.utils.PysamDispatcher('bcftools', 'gtcheck')
head = pysam.utils.PysamDispatcher('bcftools', 'head')
index = pysam.utils.PysamDispatcher('bcftools', 'index')
isec = pysam.utils.PysamDispatcher('bcftools', 'isec')
merge = pysam.utils.PysamDispatcher('bcftools', 'merge')
mpileup = pysam.utils.PysamDispatcher('bcftools', 'mpileup')
norm = pysam.utils.PysamDispatcher('bcftools', 'norm')
plugin = pysam.utils.PysamDispatcher('bcftools', 'plugin')
query = pysam.utils.PysamDispatcher('bcftools', 'query')
reheader = pysam.utils.PysamDispatcher('bcftools', 'reheader')
roh = pysam.utils.PysamDispatcher('bcftools', 'roh')
sort = pysam.utils.PysamDispatcher('bcftools', 'sort')
stats = pysam.utils.PysamDispatcher('bcftools', 'stats')
view = pysam.utils.PysamDispatcher('bcftools', 'view')

__all__ = [
    'annotate', 'call', 'cnv', 'concat', 'consensus',
    'convert', 'csq', 'filter', 'gtcheck', 'head',
    'index', 'isec', 'merge', 'mpileup', 'norm',
    'plugin', 'query', 'reheader', 'roh', 'sort',
    'stats', 'view',
]



import pysam.utils

addreplacerg = pysam.utils.PysamDispatcher('samtools', 'addreplacerg')
ampliconclip = pysam.utils.PysamDispatcher('samtools', 'ampliconclip')
ampliconstats = pysam.utils.PysamDispatcher('samtools', 'ampliconstats')
bam2fq = pysam.utils.PysamDispatcher('samtools', 'bam2fq')
bamshuf = pysam.utils.PysamDispatcher('samtools', 'bamshuf')
bedcov = pysam.utils.PysamDispatcher('samtools', 'bedcov')
calmd = pysam.utils.PysamDispatcher('samtools', 'calmd')
cat = pysam.utils.PysamDispatcher('samtools', 'cat')
collate = pysam.utils.PysamDispatcher('samtools', 'collate')
consensus = pysam.utils.PysamDispatcher('samtools', 'consensus')
coverage = pysam.utils.PysamDispatcher('samtools', 'coverage')
cram_size = pysam.utils.PysamDispatcher('samtools', 'cram-size')
depad = pysam.utils.PysamDispatcher('samtools', 'depad')
depth = pysam.utils.PysamDispatcher('samtools', 'depth')
dict = pysam.utils.PysamDispatcher('samtools', 'dict')
faidx = pysam.utils.PysamDispatcher('samtools', 'faidx')
fasta = pysam.utils.PysamDispatcher('samtools', 'fasta')
fastq = pysam.utils.PysamDispatcher('samtools', 'fastq')
fixmate = pysam.utils.PysamDispatcher('samtools', 'fixmate')
flags = pysam.utils.PysamDispatcher('samtools', 'flags')
flagstat = pysam.utils.PysamDispatcher('samtools', 'flagstat')
fqidx = pysam.utils.PysamDispatcher('samtools', 'fqidx')
fqimport = pysam.utils.PysamDispatcher('samtools', 'import')
head = pysam.utils.PysamDispatcher('samtools', 'head')
idxstats = pysam.utils.PysamDispatcher('samtools', 'idxstats')
index = pysam.utils.PysamDispatcher('samtools', 'index')
markdup = pysam.utils.PysamDispatcher('samtools', 'markdup')
merge = pysam.utils.PysamDispatcher('samtools', 'merge')
mpileup = pysam.utils.PysamDispatcher('samtools', 'mpileup')
pad2unpad = pysam.utils.PysamDispatcher('samtools', 'pad2unpad')
phase = pysam.utils.PysamDispatcher('samtools', 'phase')
quickcheck = pysam.utils.PysamDispatcher('samtools', 'quickcheck')
reference = pysam.utils.PysamDispatcher('samtools', 'reference')
reheader = pysam.utils.PysamDispatcher('samtools', 'reheader')
reset = pysam.utils.PysamDispatcher('samtools', 'reset')
rmdup = pysam.utils.PysamDispatcher('samtools', 'rmdup')
samples = pysam.utils.PysamDispatcher('samtools', 'samples')
sort = pysam.utils.PysamDispatcher('samtools', 'sort')
split = pysam.utils.PysamDispatcher('samtools', 'split')
stats = pysam.utils.PysamDispatcher('samtools', 'stats')
targetcut = pysam.utils.PysamDispatcher('samtools', 'targetcut')
tview = pysam.utils.PysamDispatcher('samtools', 'tview')
version = pysam.utils.PysamDispatcher('samtools', 'version')
view = pysam.utils.PysamDispatcher('samtools', 'view')

__all__ = [
    'addreplacerg', 'ampliconclip', 'ampliconstats',
    'bam2fq', 'bamshuf', 'bedcov', 'calmd', 'cat',
    'collate', 'consensus', 'coverage', 'cram_size',
    'depad', 'depth', 'dict', 'faidx', 'fasta',
    'fastq', 'fixmate', 'flags', 'flagstat', 'fqidx',
    'fqimport', 'head', 'idxstats', 'index',
    'markdup', 'merge', 'mpileup', 'pad2unpad',
    'phase', 'quickcheck', 'reference', 'reheader',
    'reset', 'rmdup', 'samples', 'sort', 'split',
    'stats', 'targetcut', 'tview', 'version', 'view',
]
